@@ -1,15 +1,16 @@
 package TableDataRole::Util::CSV;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-13'; # DATE
+our $DATE = '2021-06-01'; # DATE
 our $DIST = 'TableDataRoles-Standard'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use Role::Tiny;
 requires 'get_column_names';
-requires 'get_row_arrayref';
-requires 'reset_row_iterator';
+requires 'has_next_item';
+requires 'get_next_item';
+requires 'reset_iterator';
 
 sub as_csv {
     require Text::CSV_XS;
@@ -18,12 +19,13 @@ sub as_csv {
     $self->{csv_parser} //= Text::CSV_XS->new({binary=>1});
     my $csv = $self->{csv_parser};
 
-    $self->reset_row_iterator;
+    $self->reset_iterator;
 
     my $res = "";
     $csv->combine($self->get_column_names);
     $res .= $csv->string . "\n";
-    while (my $row = $self->get_row_arrayref) {
+    while ($self->has_next_item) {
+        my $row = $self->get_next_item;
         $csv->combine(@$row);
         $res .= $csv->string . "\n";
     }
@@ -45,7 +47,7 @@ TableDataRole::Util::CSV - Provide as_csv() and other CSV-related methods
 
 =head1 VERSION
 
-This document describes version 0.008 of TableDataRole::Util::CSV (from Perl distribution TableDataRoles-Standard), released on 2021-04-13.
+This document describes version 0.009 of TableDataRole::Util::CSV (from Perl distribution TableDataRoles-Standard), released on 2021-06-01.
 
 =head1 PROVIDED METHODS
 
@@ -61,7 +63,7 @@ Source repository is at L<https://github.com/perlancar/perl-TableDataRoles-Stand
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-TableDataRoles-Standard/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataRoles-Standard>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
